"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
var React = require("react");
var react_dom_1 = require("react-dom");
var Collector_1 = require("../Collector");
var dom_1 = require("../lib/dom");
var defer_1 = require("../lib/defer");
var noop_1 = require("../lib/noop");
var log_1 = require("../lib/log");
var store = require("../lib/animatorStore");
var VisibilityManager_1 = require("../VisibilityManager");
var Animator = /** @class */ (function (_super) {
    __extends(Animator, _super);
    function Animator() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.state = {
            animationsMarkup: [],
            childProps: {},
        };
        _this.animating = false;
        _this.unmounting = false;
        _this.abortAnimations = function () { return undefined; };
        _this.executeAnimations = function (DOMSnapshot) {
            if (DOMSnapshot === void 0) { DOMSnapshot = store.get(_this.props.name); }
            var _a = _this.props, name = _a.name, getContainer = _a.container, context = _a.context;
            var container = typeof getContainer === 'function' ? getContainer() : getContainer;
            var aborted = false;
            if (DOMSnapshot) {
                var collectorData = DOMSnapshot.collectorData, elementData = DOMSnapshot.elementData;
                _this.animating = true;
                // Calculate DOM data for the executing element to then be passed to the animation/s.
                var animationData_1 = {
                    origin: elementData,
                    destination: {
                        render: _this.renderChildren,
                        element: _this.element,
                        elementBoundingBox: dom_1.getElementBoundingBox(_this.element),
                        focalTargetElement: _this.focalTargetElement,
                        focalTargetElementBoundingBox: _this.focalTargetElement
                            ? dom_1.getElementBoundingBox(_this.focalTargetElement)
                            : undefined,
                    },
                };
                // Loads each action up in an easy-to-execute format.
                var actions = collectorData.map(function (targetData, index) {
                    if (targetData.action !== Collector_1.CollectorActions.animation) {
                        return targetData;
                    }
                    // Element will be lazily instantiated if we need to add something to the DOM.
                    var elementToMountChildren = null;
                    var mount = function (jsx) {
                        if (!elementToMountChildren) {
                            elementToMountChildren = document.createElement('div');
                            // We insert the new element at the beginning of the body to ensure correct stacking context.
                            container.insertBefore(elementToMountChildren, container.firstChild);
                        }
                        // This ensures that if there was an update to the jsx that is animating it changes next frame.
                        // Resulting in the transition _actually_ happening.
                        requestAnimationFrame(function () {
                            if (elementToMountChildren) {
                                _this.setState(function (prevState) {
                                    var newAnimationsMarkup = prevState.animationsMarkup.concat();
                                    newAnimationsMarkup[index] = react_dom_1.createPortal(jsx, elementToMountChildren);
                                    return {
                                        animationsMarkup: newAnimationsMarkup,
                                    };
                                });
                            }
                        });
                    };
                    var setChildProps = function (props) {
                        if (_this.unmounting) {
                            return;
                        }
                        if (props) {
                            _this.setState(function (prevState) { return ({
                                childProps: {
                                    style: props.style
                                        ? props.style(prevState.childProps.style || {})
                                        : prevState.childProps.style,
                                    className: props.className
                                        ? props.className(prevState.childProps.className)
                                        : prevState.childProps.className,
                                },
                            }); });
                        }
                        else {
                            _this.setState({
                                childProps: {},
                            });
                        }
                    };
                    var generatePhase = function (cb) { return function () {
                        if (cb) {
                            var deferred = defer_1.default();
                            var jsx = cb(animationData_1, deferred.resolve, setChildProps);
                            if (jsx) {
                                mount(jsx);
                            }
                            return deferred.promise;
                        }
                        return Promise.resolve();
                    }; };
                    return {
                        action: Collector_1.CollectorActions.animation,
                        payload: {
                            beforeAnimate: generatePhase(targetData.payload.beforeAnimate),
                            animate: generatePhase(targetData.payload.animate),
                            afterAnimate: generatePhase(targetData.payload.afterAnimate),
                            cleanup: function () {
                                if (elementToMountChildren && container.contains(elementToMountChildren)) {
                                    container.removeChild(elementToMountChildren);
                                }
                                if (targetData.payload.abort) {
                                    targetData.payload.abort();
                                }
                                if (_this.unmounting) {
                                    return;
                                }
                                _this.setState({
                                    animationsMarkup: [],
                                });
                                setChildProps(null);
                            },
                        },
                    };
                });
                var blocks_1 = actions.reduce(function (arr, targetData) {
                    switch (targetData.action) {
                        case Collector_1.CollectorActions.animation: {
                            // Add to the last block in the array.
                            arr[arr.length - 1].push(targetData.payload);
                            return arr;
                        }
                        case Collector_1.CollectorActions.wait: {
                            // Found a wait action, start a new block.
                            arr.push([]);
                            return arr;
                        }
                        default: {
                            return arr;
                        }
                    }
                }, [[]]);
                _this.abortAnimations = function () {
                    aborted = true;
                    if (_this.animating) {
                        _this.animating = false;
                        blocks_1.forEach(function (block) { return block.forEach(function (anim) { return anim.cleanup(); }); });
                    }
                };
                var beforeAnimatePromises = actions.map(function (targetData) {
                    return targetData.action === Collector_1.CollectorActions.animation
                        ? targetData.payload.beforeAnimate()
                        : Promise.resolve();
                });
                // If a VisibilityManager is a parent somewhere, notify them that we're starting animating.
                if (context) {
                    context.onStart({ name: name });
                }
                Promise.all(beforeAnimatePromises)
                    .then(function () {
                    // Wait two animation frames before triggering animations.
                    // This makes sure state set inside animate don't happen in the same animation frame as beforeAnimate.
                    var deferred = defer_1.default();
                    requestAnimationFrame(function () {
                        requestAnimationFrame(function () { return deferred.resolve(); });
                    });
                    return deferred.promise;
                })
                    .then(function () {
                    // Trigger each blocks animations, one block at a time.
                    return (blocks_1
                        // We don't care what the promises return.
                        .reduce(function (promise, block) {
                        return promise.then(function () { return Promise.all(block.map(function (anim) { return anim.animate(); })); });
                    }, Promise.resolve())
                        .then(function () {
                        // If a VisibilityManager is a parent somewhere, notify them that we're finished animating.
                        if (context) {
                            context.onFinish({ name: name });
                        }
                        // Run through all after animates.
                        return blocks_1.reduce(function (promise, block) {
                            return promise.then(function () {
                                return Promise.all(block.map(function (anim) { return anim.afterAnimate(); })).then(function () { return undefined; });
                            });
                        }, Promise.resolve());
                    })
                        .then(function () {
                        if (aborted) {
                            return;
                        }
                        blocks_1.forEach(function (block) { return block.forEach(function (anim) { return anim.cleanup(); }); });
                    })
                        .then(function () {
                        _this.animating = false;
                        var onFinish = _this.props.onFinish;
                        onFinish();
                    }));
                });
            }
        };
        _this.setRef = function (ref) {
            _this.element = ref;
        };
        _this.setTargetRef = function (ref) {
            _this.focalTargetElement = ref;
        };
        _this.setReactNode = function (renderChildren) {
            _this.renderChildren = renderChildren;
        };
        _this.setData = function (data) {
            _this.data = data;
        };
        return _this;
    }
    Animator.prototype.componentDidMount = function () {
        var _a = this.props, componentIn = _a.in, name = _a.name, triggerSelfKey = _a.triggerSelfKey;
        if (process.env.NODE_ENV === 'development' && (!triggerSelfKey && !name)) {
            log_1.warn('"name" prop needs to be defined. Without it you may have problems matching up animator targets. You will not get this error when using "triggerSelfKey" prop.');
        }
        if (componentIn === undefined && store.has(name)) {
            // A child has already been stored, so this is probably the matching pair.
            this.executeAnimations();
            return;
        }
        if (componentIn === undefined || componentIn) {
            // Ok nothing is there yet, show ourself and store DOM data for later.
            // We'll be waiting for another Animator to mount.
            this.notifyVisibilityManagerAnimationsAreFinished();
        }
    };
    Animator.prototype.getSnapshotBeforeUpdate = function (prevProps) {
        if (prevProps.in === true && this.props.in === false) {
            this.snapshotDOMData();
            this.delayedClearStore();
            this.abortAnimations();
        }
        if (prevProps.triggerSelfKey !== this.props.triggerSelfKey) {
            return this.snapshotDOMData('return');
        }
        return null;
    };
    Animator.prototype.componentDidUpdate = function (prevProps, _, DOMSnapshot) {
        var _this = this;
        var inPropSame = this.props.in === prevProps.in;
        var triggerSelfKeyPropSame = this.props.triggerSelfKey === prevProps.triggerSelfKey;
        if (inPropSame && triggerSelfKeyPropSame) {
            // Nothing has changed, return early.
            return;
        }
        if (process.env.NODE_ENV === 'development') {
            log_1.precondition(!(this.props.in !== undefined && this.props.triggerSelfKey !== undefined), "Don't use \"in\" and \"triggerSelfKey\" together. If your element is persisted use \"in\". If your element is targeting itself for animations use \"triggerSelfKey\".");
        }
        if (process.env.NODE_ENV === 'development') {
            log_1.precondition(!((this.props.in === undefined || prevProps.in === undefined) && !inPropSame), "You're switching between persisted and unpersisted, don't do this. Either always set the \"in\" prop as true or false, or keep as undefined.");
        }
        if (process.env.NODE_ENV === 'development') {
            log_1.precondition(!((this.props.triggerSelfKey === undefined || prevProps.triggerSelfKey === undefined) &&
                !triggerSelfKeyPropSame), "You're switching between self triggering modes, don't do this. Either always set the \"triggerSelfKey\" prop, or keep as undefined.");
        }
        if (this.props.in) {
            if (store.has(this.props.name)) {
                this.executeAnimations();
                // return early dont tell manager yet dawg
                return;
            }
            // No animation to trigger, tell manager we're all good regardless.
            this.notifyVisibilityManagerAnimationsAreFinished();
            return;
        }
        if (!triggerSelfKeyPropSame) {
            // Defer execution to the next frame to capture correctly.
            // Make sure to keep react state the same for any inflight animations to be captured correctly.
            requestAnimationFrame(function () {
                _this.abortAnimations();
                _this.executeAnimations(DOMSnapshot);
            });
        }
    };
    Animator.prototype.componentWillUnmount = function () {
        if (this.props.triggerSelfKey) {
            this.abortAnimations();
            this.unmounting = true;
            return;
        }
        this.snapshotDOMData();
        this.delayedClearStore();
        this.abortAnimations();
        this.unmounting = true;
    };
    Animator.prototype.notifyVisibilityManagerAnimationsAreFinished = function () {
        var _a = this.props, context = _a.context, name = _a.name;
        // If a VisibilityManager is a parent up the tree context will be available.
        // Notify them that we're finished getting ready.
        if (context) {
            context.onFinish({ name: name });
        }
    };
    Animator.prototype.delayedClearStore = function () {
        var _a = this.props, name = _a.name, timeToWaitForNextAnimator = _a.timeToWaitForNextAnimator;
        setTimeout(function () { return store.remove(name); }, timeToWaitForNextAnimator);
    };
    Animator.prototype.snapshotDOMData = function (action) {
        if (action === void 0) { action = 'store'; }
        // If there is only a Animator target and no child animations
        // data will be undefined, which means there are no animations to store.
        if (this.unmounting || !this.data) {
            return null;
        }
        if (process.env.NODE_ENV === 'development') {
            log_1.precondition(this.element, "The ref was not set when trying to store data, check that a child element has a ref passed. This needs to be set so we can take a snapshot of the origin DOM element.\n\n<" + Animator.displayName + " name=\"" + this.props.name + "\">\n  {props => <div ref={props.ref} />}\n</" + Animator.displayName + ">\n");
        }
        var elementBoundingBox = dom_1.getElementBoundingBox(this.element);
        var focalTargetElementBoundingBox = this.focalTargetElement
            ? dom_1.getElementBoundingBox(this.focalTargetElement)
            : undefined;
        if (process.env.NODE_ENV === 'development' && elementBoundingBox.size.height === 0) {
            log_1.warn("Your target child had a height of zero when capturing it's DOM data. This may affect the animation.\nIf it's an image, try and have the image loaded before mounting, or set a static height.");
        }
        var name = this.props.name;
        // NOTE: Currently in react 16.3 if the parent being unmounted is a Fragment
        // there is a chance for sibling elements to be removed from the DOM first
        // resulting in inaccurate calculations of location. Watch out!
        var data = {
            elementData: {
                element: this.element,
                elementBoundingBox: elementBoundingBox,
                focalTargetElement: this.focalTargetElement,
                focalTargetElementBoundingBox: focalTargetElementBoundingBox,
                render: this.renderChildren,
            },
            collectorData: this.data,
        };
        if (action === 'return') {
            return data;
        }
        if (action === 'store') {
            store.set(name, data);
        }
        return null;
    };
    Animator.prototype.render = function () {
        var _a = this.state, childProps = _a.childProps, animationsMarkup = _a.animationsMarkup;
        var children = this.props.children;
        return (React.createElement(React.Fragment, null,
            animationsMarkup,
            React.createElement(Collector_1.default, { topMostCollector: true, receiveData: this.setData, receiveRenderChildren: this.setReactNode, receiveRef: this.setRef, receiveFocalTargetRef: this.setTargetRef, style: childProps.style, className: childProps.className }, typeof children === 'function' ? children : React.Children.only(children))));
    };
    Animator.displayName = 'Animator';
    Animator.defaultProps = {
        onFinish: noop_1.default,
        timeToWaitForNextAnimator: 50,
        container: document.body,
        name: '',
    };
    return Animator;
}(React.PureComponent));
exports.default = Animator;
exports.WrappedAnimator = VisibilityManager_1.withVisibilityManagerContext(Animator);
//# sourceMappingURL=index.js.map