import * as React from 'react';
import { CollectorChildrenProps, AnimationCallback } from '../../Collector';
import { Duration } from '../types';
export interface FocalRevealProps extends CollectorChildrenProps {
    /**
     * How long the animation should take over {duration}ms.
     */
    duration: Duration;
    /**
     * zIndex to be applied to the moving element.
     */
    zIndex?: number;
    /**
     * Timing function to be used in the transition.
     */
    timingFunction: string;
    /**
     * Set to false to disable transforming the children to the X position of the focal element.
     * Defaults to true.
     */
    childrenTransformX: boolean;
    /**
     * Set to false to disable transforming the children to the Y position of the focal element.
     * Defaults to `true`.
     */
    childrenTransformY: boolean;
    /**
     * Will transition using clip-path over height and width.
     * This results in a more resilient transition since page flow isn't affected at the cost of browser support.
     * See: https://caniuse.com/#feat=css-clip-path
     */
    useClipPath?: boolean;
}
export default class FocalReveal extends React.Component<FocalRevealProps> {
    static defaultProps: {
        duration: string;
        timingFunction: string;
        childrenTransformX: boolean;
        childrenTransformY: boolean;
    };
    beforeAnimate: AnimationCallback;
    animate: AnimationCallback;
    render(): JSX.Element;
}
