var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
import * as React from 'react';
import Collector, { CollectorActions, } from '../../Collector';
import { calculateHypotenuse } from '../../lib/math';
import { calculateWindowCentre, calculateElementCenterInViewport, recalculateElementBoundingBoxFromScroll, getWindowDimensions, } from '../../lib/dom';
import SimpleKeyframe from '../SimpleKeyframe';
import { standard, accelerate } from '../../lib/curves';
import { zIndexStack } from '../../lib/style';
import { dynamic } from '../../lib/duration';
var CircleExpand = /** @class */ (function (_super) {
    __extends(CircleExpand, _super);
    function CircleExpand() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.renderAnimation = function (data, options) {
            var _a = _this.props, duration = _a.duration, background = _a.background, zIndex = _a.zIndex;
            // Scroll could have changed between unmount and this prepare step, let's recalculate just in case.
            var originBoundingBox = recalculateElementBoundingBoxFromScroll(data.origin.elementBoundingBox);
            var minSize = Math.min(originBoundingBox.size.width, originBoundingBox.size.height);
            var fromTargetHypotenuse = calculateHypotenuse(originBoundingBox.size);
            var fromTargetCenterInViewport = calculateElementCenterInViewport(originBoundingBox);
            var viewportCenter = calculateWindowCentre();
            var windowDimensions = getWindowDimensions();
            var windowHypotenuse = calculateHypotenuse(windowDimensions);
            var difference = {
                width: viewportCenter.left - fromTargetCenterInViewport.left,
                height: viewportCenter.top - fromTargetCenterInViewport.top,
            };
            var hypotenuseDifference = calculateHypotenuse(difference);
            var scale = Math.ceil((windowHypotenuse + hypotenuseDifference) / minSize);
            var calculatedDuration = duration === 'dynamic'
                ? dynamic(originBoundingBox, {
                    location: { left: 0, top: 0 },
                    size: windowDimensions,
                    raw: {},
                })
                : duration;
            return (React.createElement(SimpleKeyframe, { style: {
                    zIndex: zIndex,
                    left: originBoundingBox.location.left -
                        (fromTargetHypotenuse - originBoundingBox.size.width) / 2,
                    top: originBoundingBox.location.top -
                        (fromTargetHypotenuse - originBoundingBox.size.height) / 2,
                    width: fromTargetHypotenuse,
                    height: fromTargetHypotenuse,
                    borderRadius: '50%',
                    position: 'absolute',
                    background: background,
                    transition: "transform " + accelerate() + " " + calculatedDuration + "ms, opacity " + standard() + " " + calculatedDuration /
                        2 + "ms",
                    transform: 'scale(1)',
                    willChange: 'transform',
                    opacity: 1,
                }, keyframes: [
                    {
                        transform: "scale(" + scale + ")",
                    },
                    {
                        transform: "scale(" + scale + ")",
                        opacity: 0,
                    },
                ], step: options.step, onFinish: options.onFinish }));
        };
        _this.beforeAnimate = function (data, onFinish) {
            onFinish();
            return _this.renderAnimation(data, { onFinish: onFinish });
        };
        _this.animate = function (data, onFinish) {
            return _this.renderAnimation(data, { onFinish: onFinish, step: 0 });
        };
        _this.afterAnimate = function (data, onFinish) {
            return _this.renderAnimation(data, { onFinish: onFinish, step: 1 });
        };
        return _this;
    }
    CircleExpand.prototype.render = function () {
        var children = this.props.children;
        return (React.createElement(Collector, { data: {
                action: CollectorActions.animation,
                payload: {
                    beforeAnimate: this.beforeAnimate,
                    animate: this.animate,
                    afterAnimate: this.afterAnimate,
                },
            } }, children));
    };
    CircleExpand.defaultProps = {
        duration: 'dynamic',
        zIndex: zIndexStack.circleExpand,
    };
    return CircleExpand;
}(React.Component));
export default CircleExpand;
//# sourceMappingURL=index.js.map