import * as React from 'react';
import { CollectorChildrenProps, AnimationCallback } from '../../Collector';
import { Duration } from '../types';
export interface MoveProps extends CollectorChildrenProps {
    /**
     * How long the animation should take over {duration}ms.
     */
    duration: Duration;
    /**
     * zIndex to be applied to the moving element.
     */
    zIndex: number;
    /**
     * Timing function to be used in the transition.
     */
    timingFunction: string;
    /**
     * Will use <FocalTarget /> size and location for destination transform calculation.
     * Internally this is used for the <FocalRevealMove /> animation.
     */
    useFocalTarget: boolean;
    /**
     * Set to false to disable transforming the origin to the X position of the destination element.
     * Defaults to true.
     */
    transformX?: boolean;
    /**
     * Set to false to disable transforming the origin to the Y position of the destination element.
     * Defaults to `true`.
     */
    transformY?: boolean;
}
export default class Move extends React.Component<MoveProps> {
    static defaultProps: {
        duration: string;
        timingFunction: string;
        zIndex: number;
        useFocalTarget: boolean;
        transformX: boolean;
        transformY: boolean;
    };
    abort: () => void;
    beforeAnimate: AnimationCallback;
    animate: AnimationCallback;
    render(): JSX.Element;
}
